<?php
session_start();
include 'db.php';

// Redirect to login page if not logged in
if (!isset($_SESSION['loggedin']) || $_SESSION['loggedin'] !== true) {
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['user_id'];

// Initialize balances if the table is empty for the user
$result = $conn->query("SELECT * FROM balances WHERE user_id = $user_id");
if ($result->num_rows === 0) {
    $initial_balances = [
        'binance' => 0.00,
        'kucoin' => 0.00,
        'bitget' => 0.00,
        'bybit' => 0.00,
        'gate-io' => 0.00,
        'bitrue' => 0.00,
        'bitget-2' => 0.00,
        'coinstore' => 0.00,
        'mexc' => 0.00
    ];
    foreach ($initial_balances as $exchange => $amount) {
        $stmt = $conn->prepare("INSERT INTO balances (user_id, exchange, amount) VALUES (?, ?, ?)");
        $stmt->bind_param("isd", $user_id, $exchange, $amount);
        $stmt->execute();
    }
}

// Load balances from the database
$balances = [];
$result = $conn->query("SELECT * FROM balances WHERE user_id = $user_id");
while ($row = $result->fetch_assoc()) {
    $balances[$row['exchange']] = $row['amount'];
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['exchange'], $_POST['amount'], $_POST['action'])) {
    $exchange = $_POST['exchange'];
    $amount = floatval($_POST['amount']);
    $action = $_POST['action'];

    if ($amount > 0 && isset($balances[$exchange])) {
        if ($action === 'deposit') {
            $balances[$exchange] += $amount;
            $stmt = $conn->prepare("UPDATE balances SET amount = ? WHERE user_id = ? AND exchange = ?");
            $stmt->bind_param("dis", $balances[$exchange], $user_id, $exchange);
            $stmt->execute();
            $stmt = $conn->prepare("INSERT INTO transactions (user_id, exchange, amount, action) VALUES (?, ?, ?, 'deposit')");
            $stmt->bind_param("isd", $user_id, $exchange, $amount);
            $stmt->execute();
        } elseif ($action === 'withdraw' && $balances[$exchange] >= $amount) {
            $balances[$exchange] -= $amount;
            $stmt = $conn->prepare("UPDATE balances SET amount = ? WHERE user_id = ? AND exchange = ?");
            $stmt->bind_param("dis", $balances[$exchange], $user_id, $exchange);
            $stmt->execute();
            $stmt = $conn->prepare("INSERT INTO transactions (user_id, exchange, amount, action) VALUES (?, ?, ?, 'withdraw')");
            $stmt->bind_param("isd", $user_id, $exchange, $amount);
            $stmt->execute();
        } else {
            $error = "Insufficient balance for withdrawal.";
        }

        // Redirect to avoid form resubmission on refresh
        header("Location: " . $_SERVER['PHP_SELF']);
        exit();
    } else {
        $error = "Please enter a valid amount.";
    }
}

// Calculate total funds
$totalFunds = array_sum($balances);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Exchange Balances</title>
    <link rel="stylesheet" href="styles.css">
</head>
<body>
    <div class="logout-container">
        <form method="GET" action="logout.php">
            <button type="submit">Logout</button>
        </form>
    </div>
    <div class="container">
        <div class="box total-funds" id="total-funds">
            <span class="exchange-name">Total Funds</span><br>
            <span class="balance">= <?= number_format($totalFunds, 2) ?>$</span>
        </div>
        <?php foreach ($balances as $exchange => $balance): ?>
            <div class="box" id="<?= $exchange ?>">
                <span class="exchange-name"><?= strtoupper(str_replace('-', '.', $exchange)) ?></span><br>
                <span class="balance <?= $balance > 0 ? 'green' : '' ?>">= <?= number_format($balance, 2) ?>$</span>
            </div>
        <?php endforeach; ?>
    </div>

    <div class="form-container">
        <form id="add-money-form" method="POST" action="">
            <label for="exchange">Select Exchange:</label>
            <select name="exchange" id="exchange">
                <?php foreach ($balances as $exchange => $balance): ?>
                    <option value="<?= $exchange ?>"><?= strtoupper(str_replace('-', '.', $exchange)) ?></option>
                <?php endforeach; ?>
            </select>
            <label for="action">Action:</label>
            <select name="action" id="action">
                <option value="deposit">Deposit</option>
                <option value="withdraw">Withdraw</option>
            </select>
            <label for="amount">Amount:</label>
            <input type="number" name="amount" id="amount" step="0.01" required>
            <button type="submit">Submit</button>
        </form>
        <?php if (isset($error)): ?>
            <p style="color: red;"><?= $error ?></p>
        <?php endif; ?>
    </div>

    <div class="log-container">
        <h2>Transaction Log</h2>
        <ul>
            <?php
            $result = $conn->query("SELECT * FROM transactions WHERE user_id = $user_id ORDER BY timestamp DESC LIMIT 5");
            while ($row = $result->fetch_assoc()) {
                echo "<li>{$row['timestamp']} - " . ucfirst($row['action']) . " $" . number_format($row['amount'], 2) . " to/from " . strtoupper(str_replace('-', '.', $row['exchange'])) . "</li>";
            }
            ?>
        </ul>
        <form method="GET" action="all_transactions.php">
            <button type="submit">All Transactions</button>
        </form>
    </div>
</body>
</html>
