<?php
session_start();

// Define a hardcoded password (in a real application, use a more secure method)
$correct_password = '1234';

// Handle login
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['password'])) {
    if ($_POST['password'] === $correct_password) {
        $_SESSION['loggedin'] = true;
        header("Location: " . $_SERVER['PHP_SELF']);
        exit();
    } else {
        $login_error = "Incorrect password. Please try again.";
    }
}

// Handle logout
if (isset($_GET['logout'])) {
    session_destroy();
    header("Location: " . $_SERVER['PHP_SELF']);
    exit();
}

// Redirect to login page if not logged in
if (!isset($_SESSION['loggedin']) || $_SESSION['loggedin'] !== true) {
    include 'login.php';
    exit();
}

// Define file paths
$balances_file = 'balances.json';
$log_file = 'log.txt';

// Initialize balances if the file doesn't exist
if (!file_exists($balances_file)) {
    $initial_balances = [
        'binance' => 0.00,
        'kucoin' => 0.00,
        'bitget' => 0.00,
        'bybit' => 0.00,
        'gate-io' => 0.00,
        'bitrue' => 0.00,
        'bitget-2' => 0.00,
        'coinstore' => 0.00,
        'mexc' => 0.00,
        'xt-com' => 0.00 // Added XT.com exchange
    ];
    file_put_contents($balances_file, json_encode($initial_balances));
}

// Load balances from the file
$balances = json_decode(file_get_contents($balances_file), true);

// Ensure 'mexc' and 'xt-com' are in the balances array if the file already exists
if (!isset($balances['mexc'])) {
    $balances['mexc'] = 0.00;
}
if (!isset($balances['xt-com'])) {
    $balances['xt-com'] = 0.00;
    file_put_contents($balances_file, json_encode($balances));
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['exchange'], $_POST['amount'], $_POST['action'])) {
    $exchange = $_POST['exchange'];
    $amount = floatval($_POST['amount']);
    $action = $_POST['action'];

    if ($amount > 0 && isset($balances[$exchange])) {
        if ($action === 'deposit') {
            $balances[$exchange] += $amount;
            $log_entry = date('Y-m-d H:i:s') . " - Deposited $" . number_format($amount, 2) . " to " . strtoupper(str_replace('-', '.', $exchange)) . "\n";
        } elseif ($action === 'withdraw' && $balances[$exchange] >= $amount) {
            $balances[$exchange] -= $amount;
            $log_entry = date('Y-m-d H:i:s') . " - Withdrew $" . number_format($amount, 2) . " from " . strtoupper(str_replace('-', '.', $exchange)) . "\n";
        } else {
            $error = "Insufficient balance for withdrawal.";
        }

        // Save the updated balances back to the file
        file_put_contents($balances_file, json_encode($balances));

        // Log the transaction
        if (isset($log_entry)) {
            file_put_contents($log_file, $log_entry, FILE_APPEND);

            // Redirect to avoid form resubmission on refresh
            header("Location: " . $_SERVER['PHP_SELF']);
            exit();
        }
    } else {
        $error = "Please enter a valid amount.";
    }
}

// Sort balances so that exchanges with funds are displayed first
uasort($balances, function($a, $b) {
    return $b - $a;
});

// Calculate total funds
$totalFunds = array_sum($balances);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Exchange Balances</title>
    <link rel="stylesheet" href="styles.css">
</head>
<body>
    <div class="logout-container">
        <form method="GET" action="">
            <button type="submit" name="logout">Logout</button>
        </form>
    </div>
    <div class="container">
        <div class="box total-funds" id="total-funds">
            <span class="exchange-name">Total Funds</span><br>
            <span class="balance">= <?= number_format($totalFunds, 2) ?>$</span>
        </div>
        <?php foreach ($balances as $exchange => $balance): ?>
            <div class="box" id="<?= $exchange ?>">
                <span class="exchange-name"><?= strtoupper(str_replace('-', '.', $exchange)) ?></span><br>
                <span class="balance <?= $balance > 0 ? 'green' : '' ?>">= <?= number_format($balance, 2) ?>$</span>
            </div>
        <?php endforeach; ?>
    </div>

    <div class="form-container">
        <form id="add-money-form" method="POST" action="">
            <label for="exchange">Select Exchange:</label>
            <select name="exchange" id="exchange">
                <?php foreach ($balances as $exchange => $balance): ?>
                    <option value="<?= $exchange ?>"><?= strtoupper(str_replace('-', '.', $exchange)) ?></option>
                <?php endforeach; ?>
            </select>
            <label for="action">Action:</label>
            <select name="action" id="action">
                <option value="deposit">Deposit</option>
                <option value="withdraw">Withdraw</option>
            </select>
            <label for="amount">Amount:</label>
            <input type="number" name="amount" id="amount" step="0.01" required>
            <button type="submit">Submit</button>
        </form>
        <?php if (isset($error)): ?>
            <p style="color: red;"><?= $error ?></p>
        <?php endif; ?>
    </div>

    <div class="log-container">
        <h2>Transaction Log</h2>
        <ul>
            <?php
            if (file_exists($log_file)) {
                $log_entries = array_reverse(file($log_file, FILE_IGNORE_NEW_LINES));
                $last_five_entries = array_slice($log_entries, 0, 5);
                foreach ($last_five_entries as $entry) {
                    echo "<li>$entry</li>";
                }
            }
            ?>
        </ul>
        <form method="GET" action="all_transactions.php">
            <button type="submit">All Transactions</button>
        </form>
    </div>
</body>
</html>
